==> slayersbeasts-fabric-1.21.1-5.2.0-sources.jar: net/invictusslayer/slayersbeasts/client/model/AntSoldierModel.java <==
package net.invictusslayer.slayersbeasts.client.model;

import net.invictusslayer.slayersbeasts.SlayersBeasts;
import net.invictusslayer.slayersbeasts.client.animation.AntSoldierAnimation;
import net.invictusslayer.slayersbeasts.world.entity.AntSoldier;
import net.minecraft.class_2960;
import net.minecraft.class_5597;
import net.minecraft.class_5601;
import net.minecraft.class_5603;
import net.minecraft.class_5605;
import net.minecraft.class_5606;
import net.minecraft.class_5607;
import net.minecraft.class_5609;
import net.minecraft.class_5610;
import net.minecraft.class_630;
import net.minecraft.client.model.geom.builders.*;

public class AntSoldierModel<T extends AntSoldier> extends class_5597<T> {
	public static final class_5601 LAYER_LOCATION = new class_5601(class_2960.method_60655(SlayersBeasts.MOD_ID, "ant_soldier_model"), "main");
	private final class_630 root;

	public AntSoldierModel(class_630 root) {
		this.root = root;
	}

	public class_630 method_32008() {
		return root;
	}

	public void setupAnim(T entity, float limbSwing, float limbSwingAmount, float ageInTicks, float netHeadYaw, float headPitch) {
		root.method_32088().forEach(class_630::method_41923);
		method_48741(AntSoldierAnimation.WALK, limbSwing, limbSwingAmount, 15, 10);
	}

	public static class_5607 createBodyLayer() {
		class_5609 meshdefinition = new class_5609();
		class_5610 partdefinition = meshdefinition.method_32111();

		class_5610 body = partdefinition.method_32117("body", class_5606.method_32108(), class_5603.method_32090(0.0F, 23.0F, 0.0F));

		class_5610 cube_r1 = body.method_32117("cube_r1", class_5606.method_32108().method_32101(26, 28).method_32098(-2.0F, 1.25F, 8.0F, 4.0F, 2.0F, 1.0F, new class_5605(0.0F))
				.method_32101(28, 6).method_32098(-3.0F, -0.5F, 7.0F, 6.0F, 4.0F, 1.0F, new class_5605(0.0F))
				.method_32101(14, 27).method_32098(-2.5F, -0.75F, 0.0F, 5.0F, 4.0F, 1.0F, new class_5605(0.0F))
				.method_32101(0, 0).method_32098(-4.0F, -1.25F, 1.0F, 8.0F, 5.0F, 6.0F, new class_5605(0.0F)), class_5603.method_32091(0.0F, -6.5F, 6.0F, -0.2618F, 0.0F, 0.0F));

		class_5610 cube_r2 = body.method_32117("cube_r2", class_5606.method_32108().method_32101(0, 0).method_32098(0.0F, -1.2588F, -1.9659F, 1.0F, 2.0F, 2.0F, new class_5605(0.0F)), class_5603.method_32091(-2.0F, -4.4635F, -11.4686F, 0.2618F, -0.2618F, 0.0F));

		class_5610 cube_r3 = body.method_32117("cube_r3", class_5606.method_32108().method_32101(0, 11).method_32098(-1.0F, -1.2588F, -1.9659F, 1.0F, 2.0F, 2.0F, new class_5605(0.0F)), class_5603.method_32091(2.0F, -4.4635F, -11.4686F, 0.2618F, 0.2618F, 0.0F));

		class_5610 cube_r4 = body.method_32117("cube_r4", class_5606.method_32108().method_32101(0, 11).method_32098(-3.0F, -1.0F, -7.0F, 6.0F, 4.0F, 7.0F, new class_5605(0.0F)), class_5603.method_32091(0.0F, -7.5F, -5.0F, 0.2618F, 0.0F, 0.0F));

		class_5610 cube_r5 = body.method_32117("cube_r5", class_5606.method_32108().method_32101(0, 22).method_32098(-1.0F, 0.0F, -5.0F, 2.0F, 2.0F, 5.0F, new class_5605(0.0F)), class_5603.method_32091(0.0F, -6.5F, 6.0F, 0.2618F, 0.0F, 0.0F));

		class_5610 cube_r6 = body.method_32117("cube_r6", class_5606.method_32108().method_32101(18, 14).method_32098(-1.5F, 0.0F, 0.0F, 3.0F, 3.0F, 8.0F, new class_5605(0.0F)), class_5603.method_32091(0.0F, -7.5F, -5.0F, -0.1745F, 0.0F, 0.0F));

		class_5610 antenna_left = body.method_32117("antenna_left", class_5606.method_32108().method_32101(0, 29).method_32098(0.0F, -7.25F, -7.0F, 0.0F, 8.0F, 8.0F, new class_5605(0.0F)), class_5603.method_32091(1.0F, -7.75F, -8.0F, 0.2618F, -0.1745F, 0.1745F));

		class_5610 antenna_right = body.method_32117("antenna_right", class_5606.method_32108().method_32101(16, 28).method_32098(0.0F, -7.25F, -7.0F, 0.0F, 8.0F, 8.0F, new class_5605(0.0F)), class_5603.method_32091(-1.0F, -7.75F, -8.0F, 0.2618F, 0.1745F, -0.1745F));

		class_5610 leg_left_front = body.method_32117("leg_left_front", class_5606.method_32108().method_32101(32, 16).method_32098(0.0F, 0.0F, -0.5F, 4.0F, 2.0F, 1.0F, new class_5605(0.0F))
				.method_32101(26, 26).method_32098(3.0F, -4.0F, -0.5F, 8.0F, 1.0F, 1.0F, new class_5605(0.0F)), class_5603.method_32091(1.5F, -5.5F, -1.5F, 0.6283F, 0.6283F, 1.2566F));

		class_5610 cube_r7 = leg_left_front.method_32117("cube_r7", class_5606.method_32108().method_32101(19, 34).method_32098(0.0F, -1.0F, 0.0F, 3.0F, 1.0F, 1.0F, new class_5605(0.0F)), class_5603.method_32091(4.0F, 0.0F, -0.5F, 0.0F, 0.0F, -1.5708F));

		class_5610 leg_left_mid = body.method_32117("leg_left_mid", class_5606.method_32108().method_32101(32, 13).method_32098(0.0F, 0.0F, -0.5F, 4.0F, 2.0F, 1.0F, new class_5605(0.0F))
				.method_32101(9, 25).method_32098(3.0F, -4.0F, -0.5F, 8.0F, 1.0F, 1.0F, new class_5605(0.0F)), class_5603.method_32091(1.5F, -5.0F, 0.0F, 0.0F, 0.0F, 0.8796F));

		class_5610 cube_r8 = leg_left_mid.method_32117("cube_r8", class_5606.method_32108().method_32101(32, 19).method_32098(0.0F, -1.0F, 0.0F, 3.0F, 1.0F, 1.0F, new class_5605(0.0F)), class_5603.method_32091(4.0F, 0.0F, -0.5F, 0.0F, 0.0F, -1.5708F));

		class_5610 leg_left_hind = body.method_32117("leg_left_hind", class_5606.method_32108().method_32101(25, 31).method_32098(0.0F, 0.0F, -0.5F, 4.0F, 2.0F, 1.0F, new class_5605(0.0F))
				.method_32101(22, 4).method_32098(3.0F, -4.0F, -0.5F, 8.0F, 1.0F, 1.0F, new class_5605(0.0F)), class_5603.method_32091(1.5F, -4.5F, 1.5F, -0.6283F, -0.6283F, 1.0996F));

		class_5610 cube_r9 = leg_left_hind.method_32117("cube_r9", class_5606.method_32108().method_32101(9, 22).method_32098(0.0F, -1.0F, 0.0F, 3.0F, 1.0F, 1.0F, new class_5605(0.0F)), class_5603.method_32091(4.0F, 0.0F, -0.5F, 0.0F, 0.0F, -1.5708F));

		class_5610 leg_right_front = body.method_32117("leg_right_front", class_5606.method_32108().method_32101(10, 32).method_32098(-4.0F, 0.0F, -0.5F, 4.0F, 2.0F, 1.0F, new class_5605(0.0F))
				.method_32101(19, 11).method_32098(-11.0F, -4.0F, -0.5F, 8.0F, 1.0F, 1.0F, new class_5605(0.0F)), class_5603.method_32091(-1.5F, -5.5F, -1.5F, 0.6283F, -0.6283F, -1.2566F));

		class_5610 cube_r10 = leg_right_front.method_32117("cube_r10", class_5606.method_32108().method_32101(27, 34).method_32098(-3.0F, -1.0F, 0.0F, 3.0F, 1.0F, 1.0F, new class_5605(0.0F)), class_5603.method_32091(-4.0F, 0.0F, -0.5F, 0.0F, 0.0F, 1.5708F));

		class_5610 leg_right_mid = body.method_32117("leg_right_mid", class_5606.method_32108().method_32101(0, 32).method_32098(-4.0F, 0.0F, -0.5F, 4.0F, 2.0F, 1.0F, new class_5605(0.0F))
				.method_32101(22, 0).method_32098(-11.0F, -4.0F, -0.5F, 8.0F, 1.0F, 1.0F, new class_5605(0.0F)), class_5603.method_32091(-1.5F, -5.0F, 0.0F, 0.0F, 0.0F, -0.8796F));

		class_5610 cube_r11 = leg_right_mid.method_32117("cube_r11", class_5606.method_32108().method_32101(34, 33).method_32098(-3.0F, -1.0F, 0.0F, 3.0F, 1.0F, 1.0F, new class_5605(0.0F)), class_5603.method_32091(-4.0F, 0.0F, -0.5F, 0.0F, 0.0F, 1.5708F));

		class_5610 leg_right_hind = body.method_32117("leg_right_hind", class_5606.method_32108().method_32101(0, 29).method_32098(-4.0F, 0.0F, -0.5F, 4.0F, 2.0F, 1.0F, new class_5605(0.0F))
				.method_32101(22, 2).method_32098(-11.0F, -4.0F, -0.5F, 8.0F, 1.0F, 1.0F, new class_5605(0.0F)), class_5603.method_32091(-1.5F, -4.5F, 1.5F, -0.6283F, 0.6283F, -1.0996F));

		class_5610 cube_r12 = leg_right_hind.method_32117("cube_r12", class_5606.method_32108().method_32101(0, 35).method_32098(-3.0F, -1.0F, 0.0F, 3.0F, 1.0F, 1.0F, new class_5605(0.0F)), class_5603.method_32091(-4.0F, 0.0F, -0.5F, 0.0F, 0.0F, 1.5708F));

		return class_5607.method_32110(meshdefinition, 64, 64);
	}
}

==> slayersbeasts-fabric-1.21.4-6.2.0-sources.jar: net/invictusslayer/slayersbeasts/client/model/AntSoldierModel.java <==
package net.invictusslayer.slayersbeasts.client.model;

import net.invictusslayer.slayersbeasts.SlayersBeasts;
import net.invictusslayer.slayersbeasts.client.animation.AntSoldierAnimation;
import net.invictusslayer.slayersbeasts.client.state.AntSoldierRenderState;
import net.minecraft.class_2960;
import net.minecraft.class_5601;
import net.minecraft.class_5603;
import net.minecraft.class_5605;
import net.minecraft.class_5606;
import net.minecraft.class_5607;
import net.minecraft.class_5609;
import net.minecraft.class_5610;
import net.minecraft.class_583;
import net.minecraft.class_630;
import net.minecraft.client.model.geom.builders.*;

public class AntSoldierModel extends class_583<AntSoldierRenderState> {
	public static final class_5601 LAYER_LOCATION = new class_5601(class_2960.method_60655(SlayersBeasts.MOD_ID, "ant_soldier_model"), "main");

	public AntSoldierModel(class_630 root) {
		super(root);
	}

	public void setupAnim(AntSoldierRenderState state) {
		super.method_2819(state);
		method_62102(AntSoldierAnimation.WALK, state.field_53450, state.field_53451, 15, 10);
	}

	public static class_5607 createBodyLayer() {
		class_5609 meshdefinition = new class_5609();
		class_5610 partdefinition = meshdefinition.method_32111();

		class_5610 body = partdefinition.method_32117("body", class_5606.method_32108(), class_5603.method_32090(0.0F, 23.0F, 0.0F));

		class_5610 cube_r1 = body.method_32117("cube_r1", class_5606.method_32108().method_32101(26, 28).method_32098(-2.0F, 1.25F, 8.0F, 4.0F, 2.0F, 1.0F, new class_5605(0.0F))
				.method_32101(28, 6).method_32098(-3.0F, -0.5F, 7.0F, 6.0F, 4.0F, 1.0F, new class_5605(0.0F))
				.method_32101(14, 27).method_32098(-2.5F, -0.75F, 0.0F, 5.0F, 4.0F, 1.0F, new class_5605(0.0F))
				.method_32101(0, 0).method_32098(-4.0F, -1.25F, 1.0F, 8.0F, 5.0F, 6.0F, new class_5605(0.0F)), class_5603.method_32091(0.0F, -6.5F, 6.0F, -0.2618F, 0.0F, 0.0F));

		class_5610 cube_r2 = body.method_32117("cube_r2", class_5606.method_32108().method_32101(0, 0).method_32098(0.0F, -1.2588F, -1.9659F, 1.0F, 2.0F, 2.0F, new class_5605(0.0F)), class_5603.method_32091(-2.0F, -4.4635F, -11.4686F, 0.2618F, -0.2618F, 0.0F));

		class_5610 cube_r3 = body.method_32117("cube_r3", class_5606.method_32108().method_32101(0, 11).method_32098(-1.0F, -1.2588F, -1.9659F, 1.0F, 2.0F, 2.0F, new class_5605(0.0F)), class_5603.method_32091(2.0F, -4.4635F, -11.4686F, 0.2618F, 0.2618F, 0.0F));

		class_5610 cube_r4 = body.method_32117("cube_r4", class_5606.method_32108().method_32101(0, 11).method_32098(-3.0F, -1.0F, -7.0F, 6.0F, 4.0F, 7.0F, new class_5605(0.0F)), class_5603.method_32091(0.0F, -7.5F, -5.0F, 0.2618F, 0.0F, 0.0F));

		class_5610 cube_r5 = body.method_32117("cube_r5", class_5606.method_32108().method_32101(0, 22).method_32098(-1.0F, 0.0F, -5.0F, 2.0F, 2.0F, 5.0F, new class_5605(0.0F)), class_5603.method_32091(0.0F, -6.5F, 6.0F, 0.2618F, 0.0F, 0.0F));

		class_5610 cube_r6 = body.method_32117("cube_r6", class_5606.method_32108().method_32101(18, 14).method_32098(-1.5F, 0.0F, 0.0F, 3.0F, 3.0F, 8.0F, new class_5605(0.0F)), class_5603.method_32091(0.0F, -7.5F, -5.0F, -0.1745F, 0.0F, 0.0F));

		class_5610 antenna_left = body.method_32117("antenna_left", class_5606.method_32108().method_32101(0, 29).method_32098(0.0F, -7.25F, -7.0F, 0.0F, 8.0F, 8.0F, new class_5605(0.0F)), class_5603.method_32091(1.0F, -7.75F, -8.0F, 0.2618F, -0.1745F, 0.1745F));

		class_5610 antenna_right = body.method_32117("antenna_right", class_5606.method_32108().method_32101(16, 28).method_32098(0.0F, -7.25F, -7.0F, 0.0F, 8.0F, 8.0F, new class_5605(0.0F)), class_5603.method_32091(-1.0F, -7.75F, -8.0F, 0.2618F, 0.1745F, -0.1745F));

		class_5610 leg_left_front = body.method_32117("leg_left_front", class_5606.method_32108().method_32101(32, 16).method_32098(0.0F, 0.0F, -0.5F, 4.0F, 2.0F, 1.0F, new class_5605(0.0F))
				.method_32101(26, 26).method_32098(3.0F, -4.0F, -0.5F, 8.0F, 1.0F, 1.0F, new class_5605(0.0F)), class_5603.method_32091(1.5F, -5.5F, -1.5F, 0.6283F, 0.6283F, 1.2566F));

		class_5610 cube_r7 = leg_left_front.method_32117("cube_r7", class_5606.method_32108().method_32101(19, 34).method_32098(0.0F, -1.0F, 0.0F, 3.0F, 1.0F, 1.0F, new class_5605(0.0F)), class_5603.method_32091(4.0F, 0.0F, -0.5F, 0.0F, 0.0F, -1.5708F));

		class_5610 leg_left_mid = body.method_32117("leg_left_mid", class_5606.method_32108().method_32101(32, 13).method_32098(0.0F, 0.0F, -0.5F, 4.0F, 2.0F, 1.0F, new class_5605(0.0F))
				.method_32101(9, 25).method_32098(3.0F, -4.0F, -0.5F, 8.0F, 1.0F, 1.0F, new class_5605(0.0F)), class_5603.method_32091(1.5F, -5.0F, 0.0F, 0.0F, 0.0F, 0.8796F));

		class_5610 cube_r8 = leg_left_mid.method_32117("cube_r8", class_5606.method_32108().method_32101(32, 19).method_32098(0.0F, -1.0F, 0.0F, 3.0F, 1.0F, 1.0F, new class_5605(0.0F)), class_5603.method_32091(4.0F, 0.0F, -0.5F, 0.0F, 0.0F, -1.5708F));

		class_5610 leg_left_hind = body.method_32117("leg_left_hind", class_5606.method_32108().method_32101(25, 31).method_32098(0.0F, 0.0F, -0.5F, 4.0F, 2.0F, 1.0F, new class_5605(0.0F))
				.method_32101(22, 4).method_32098(3.0F, -4.0F, -0.5F, 8.0F, 1.0F, 1.0F, new class_5605(0.0F)), class_5603.method_32091(1.5F, -4.5F, 1.5F, -0.6283F, -0.6283F, 1.0996F));

		class_5610 cube_r9 = leg_left_hind.method_32117("cube_r9", class_5606.method_32108().method_32101(9, 22).method_32098(0.0F, -1.0F, 0.0F, 3.0F, 1.0F, 1.0F, new class_5605(0.0F)), class_5603.method_32091(4.0F, 0.0F, -0.5F, 0.0F, 0.0F, -1.5708F));

		class_5610 leg_right_front = body.method_32117("leg_right_front", class_5606.method_32108().method_32101(10, 32).method_32098(-4.0F, 0.0F, -0.5F, 4.0F, 2.0F, 1.0F, new class_5605(0.0F))
				.method_32101(19, 11).method_32098(-11.0F, -4.0F, -0.5F, 8.0F, 1.0F, 1.0F, new class_5605(0.0F)), class_5603.method_32091(-1.5F, -5.5F, -1.5F, 0.6283F, -0.6283F, -1.2566F));

		class_5610 cube_r10 = leg_right_front.method_32117("cube_r10", class_5606.method_32108().method_32101(27, 34).method_32098(-3.0F, -1.0F, 0.0F, 3.0F, 1.0F, 1.0F, new class_5605(0.0F)), class_5603.method_32091(-4.0F, 0.0F, -0.5F, 0.0F, 0.0F, 1.5708F));

		class_5610 leg_right_mid = body.method_32117("leg_right_mid", class_5606.method_32108().method_32101(0, 32).method_32098(-4.0F, 0.0F, -0.5F, 4.0F, 2.0F, 1.0F, new class_5605(0.0F))
				.method_32101(22, 0).method_32098(-11.0F, -4.0F, -0.5F, 8.0F, 1.0F, 1.0F, new class_5605(0.0F)), class_5603.method_32091(-1.5F, -5.0F, 0.0F, 0.0F, 0.0F, -0.8796F));

		class_5610 cube_r11 = leg_right_mid.method_32117("cube_r11", class_5606.method_32108().method_32101(34, 33).method_32098(-3.0F, -1.0F, 0.0F, 3.0F, 1.0F, 1.0F, new class_5605(0.0F)), class_5603.method_32091(-4.0F, 0.0F, -0.5F, 0.0F, 0.0F, 1.5708F));

		class_5610 leg_right_hind = body.method_32117("leg_right_hind", class_5606.method_32108().method_32101(0, 29).method_32098(-4.0F, 0.0F, -0.5F, 4.0F, 2.0F, 1.0F, new class_5605(0.0F))
				.method_32101(22, 2).method_32098(-11.0F, -4.0F, -0.5F, 8.0F, 1.0F, 1.0F, new class_5605(0.0F)), class_5603.method_32091(-1.5F, -4.5F, 1.5F, -0.6283F, 0.6283F, -1.0996F));

		class_5610 cube_r12 = leg_right_hind.method_32117("cube_r12", class_5606.method_32108().method_32101(0, 35).method_32098(-3.0F, -1.0F, 0.0F, 3.0F, 1.0F, 1.0F, new class_5605(0.0F)), class_5603.method_32091(-4.0F, 0.0F, -0.5F, 0.0F, 0.0F, 1.5708F));

		return class_5607.method_32110(meshdefinition, 64, 64);
	}
}
